==> gridstack-8.x-2.11.tar.gz: gridstack/src/Entity/GridStackBase.php <==
<?php

namespace Drupal\gridstack\Entity;

use Drupal\Component\Utility\NestedArray;
use Drupal\Component\Utility\Random;
use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\blazy\Blazy;
use Drupal\gridstack\GridStackDefault;

/**
 * Defines the base class for GridStack configuration entity.
 *
 * @see \Drupal\gridstack\Entity\GridStack
 * @see \Drupal\outlayer\Entity\Outlayer
 */
abstract class GridStackBase extends ConfigEntityBase implements GridStackBaseInterface {

  /**
   * The legacy CTools ID for the configurable optionset.
   *
   * @var string
   */
  protected $name;

  /**
   * The human-readable name for the optionset.
   *
   * @var string
   */
  protected $label;

  /**
   * The administrative description.
   *
   * @var string
   */
  protected $description = '';

  /**
   * The weight to re-arrange the order of gridstack optionsets.
   *
   * @var int
   */
  protected $weight = 0;

  /**
   * The plugin instance json to reduce frontend logic.
   *
   * @var string
   */
  protected $json = '';

  /**
   * The plugin instance options.
   *
   * @var array
   */
  protected $options = [];

  /**
   * The variant source.
   *
   * @var string
   */
  protected $source = '';

  /**
   * Overrides Drupal\Core\Entity\Entity::id().
   */
  public function id() {
    return $this->name;
  }

  /**
   * {@inheritdoc}
   */
  public function description(): string {
    return $this->description;
  }

  /**
   * {@inheritdoc}
   */
  public function source(): string {
    return $this->source;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return self::load('default')->getOptions('settings');
  }

  /**
   * {@inheritdoc}
   */
  public function getOptions($group = NULL, $property = NULL) {
    $default = self::load('default');
    $default_options = $default ? $default->options : [];
    $options = $this->options ? NestedArray::mergeDeep($default_options, $this->options) : $default_options;
    if ($group) {
      if (is_array($group)) {
        return NestedArray::getValue($options, $group);
      }
      elseif (isset($property) && isset($options[$group])) {
        return $options[$group][$property] ?? NULL;
      }
      return $options[$group] ?? $options;
    }
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function setOptions(array $options = [], $merged = TRUE) {
    $this->options = $merged ? NestedArray::mergeDeep($this->options, $options) : $options;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOption($group, $default = NULL) {
    // Makes sure to not call ::getOptions($group), else everything is dumped.
    return $this->getOptions()[$group] ?? $default;
  }

  /**
   * {@inheritdoc}
   */
  public function setOption($group, $value) {
    $value = $group == 'settings' ? array_merge(($this->options[$group] ?? []), $value) : $value;
    $this->options[$group] = $value;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getJson($group = '') {
    $default = self::load('default');
    if ($group) {
      $defaults = $default->json[$group] ?? '';
      return $this->json[$group] ?? $defaults;
    }
    return $this->json;
  }

  /**
   * {@inheritdoc}
   */
  public function setJson($group, $value) {
    $this->json[$group] = $value;
    return $this;
  }

  /**
   * Load the optionset with a fallback.
   */
  public static function loadWithFallback($id) {
    $optionset = self::load($id);

    // Ensures deleted optionset while being used doesn't screw up.
    return empty($optionset) ? self::load('default') : $optionset;
  }

  /**
   * {@inheritdoc}
   */
  public function buildIconFileUri($dir = 'gridstack', $extension = 'png'): string {
    $path = $dir . '/' . $this->id() . '.' . $extension;
    if (method_exists(Blazy::class, 'normalizeUri')) {
      return Blazy::normalizeUri($path);
    }
    // @todo remove post Blazy:2.10.
    $stream = GridStackDefault::streamWrapperManager();
    return $stream ? $stream->normalizeUri($path) : $path;
  }

  /**
   * {@inheritdoc}
   */
  public function getIconFileUri($dir = 'gridstack', $extension = 'png'): ?string {
    $uri = $this->buildIconFileUri($dir, $extension);
    return is_file($uri) ? $uri : NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function randomize($rand = 4) {
    $random = new Random();
    return mb_strtolower($random->name($rand));
  }

  /**
   * {@inheritdoc}
   */
  public function getLabelFromId($label) {
    $names = strpos($label, '__') === FALSE ? explode("_", $label) : explode("__", $label);
    return implode(" ", $names);
  }

  /**
   * {@inheritdoc}
   */
  public function getRandomizedId($rand = 4) {
    $id = $this->id();
    $names = strpos($id, '__') === FALSE ? explode("_", $id) : explode("__", $id);
    if (count($names) > 1) {
      array_pop($names);
    }
    return implode("__", $names) . '__' . $this->randomize($rand);
  }

}

==> gridstack-8.x-2.12-rc4.tar.gz: gridstack/src/Entity/GridStackBase.php <==
<?php

namespace Drupal\gridstack\Entity;

use Drupal\blazy\Blazy;
use Drupal\blazy\Config\Entity\BlazyConfigEntityBase;
use Drupal\Component\Utility\Random;

/**
 * Defines the base class for GridStack configuration entity.
 *
 * @see \Drupal\gridstack\Entity\GridStack
 * @see \Drupal\outlayer\Entity\Outlayer
 *
 * @phpstan-ignore-next-line
 */
abstract class GridStackBase extends BlazyConfigEntityBase implements GridStackBaseInterface {

  /**
   * The administrative description.
   *
   * @var string
   */
  protected $description = '';

  /**
   * The plugin instance json to reduce frontend logic.
   *
   * @var string
   */
  protected $json = '';

  /**
   * The variant source.
   *
   * @var string
   */
  protected $source = '';

  /**
   * {@inheritdoc}
   */
  public function description(): string {
    return $this->description;
  }

  /**
   * {@inheritdoc}
   */
  public function source(): string {
    return $this->source;
  }

  /**
   * {@inheritdoc}
   */
  public function getJson($group = '') {
    $default = self::load('default');
    if ($group) {
      $defaults = $default->json[$group] ?? '';
      return $this->json[$group] ?? $defaults;
    }
    return $this->json;
  }

  /**
   * {@inheritdoc}
   */
  public function setJson($group, $value) {
    $this->json[$group] = $value;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function buildIconFileUri($dir = 'gridstack', $extension = 'png'): string {
    $path = $dir . '/' . $this->id() . '.' . $extension;
    return Blazy::normalizeUri($path);
  }

  /**
   * {@inheritdoc}
   */
  public function getIconFileUri($dir = 'gridstack', $extension = 'png'): ?string {
    $uri = $this->buildIconFileUri($dir, $extension);
    return is_file($uri) ? $uri : NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function randomize($rand = 4) {
    $random = new Random();
    return strtolower($random->name($rand));
  }

  /**
   * {@inheritdoc}
   */
  public function getLabelFromId($label) {
    $names = strpos($label, '__') === FALSE ? explode("_", $label) : explode("__", $label);
    return implode(" ", $names);
  }

  /**
   * {@inheritdoc}
   */
  public function getRandomizedId($rand = 4) {
    $id = $this->id();
    $names = strpos($id, '__') === FALSE ? explode("_", $id) : explode("__", $id);
    if (count($names) > 1) {
      array_pop($names);
    }
    return implode("__", $names) . '__' . $this->randomize($rand);
  }

}
